/*                                                 -*-mode:C;tab-width:8-*-
 * 
 * pxgain.c -- change the current gain of the px500 grabber
 *
 * Copyright (C) 1997 Alessandro Rubini  -- rubini@linux.it
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>
#include <ctype.h>
#include <sys/ioctl.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <fcntl.h>

#include "px500.h"

int main(int argc, char **argv)
{
    char *devicename="/dev/px0ctl";
    char *prgname = argv[0];
    Px_Gain gain;
    int fd;

    if (argc>1 && argv[1][1]=='-') {
        fprintf(stderr,"%s: set or get px500 gain\n", argv[0]);
        fprintf(stderr,"  Usage: \"%s [<device>] [<grossgain> <finegain>]\" "
                "to set gain\n",argv[0]);
        fprintf(stderr,"         \"%s [<device>]\" to get gain. "
                "Uses /dev/px0ctl by default\n",argv[0]);
        exit(1);

    }

    if (argc>1 && argv[1][0]=='/') {
        devicename=argv[1];
        argv++; argc--;
    }

    fd=open(devicename,O_RDONLY);
    if (fd < 0) {
        fprintf(stderr,"%s: open(%s): %s\n",prgname,devicename,
                strerror(errno));
        exit(1);
    }

    if (argc == 1) {
        if(Px_GetGain(fd,&gain)) {
        fprintf(stderr,"%s: ioctl(%s,getgain): %s\n",prgname,devicename,
                strerror(errno));
        exit(1);
        }
        printf("%s: %i %i\n",devicename,gain.range,gain.fine);
        exit(0);
    }

    if (!strcmp(argv[1],"auto")) {
        int autogain = 5;
        if (argc == 3) {
            autogain = atoi(argv[2]);
        }
        if (Px_AutoGain(fd,autogain)) {
            fprintf(stderr,"%s: ioctl(%s,autogain %i): %s\n",
                    prgname,devicename,autogain,strerror(errno));
            exit(1);
        }
        exit(0);
    }

    if (argc != 3 || !isdigit(argv[1][0]) || !isdigit(argv[2][0])) {
        fprintf(stderr,"%s: invalid gain. Try \"%s -h\"\n",prgname,prgname);
        exit(1);
    }

    gain.range = atoi(argv[1]);
    gain.fine  = atoi(argv[2]);
    if(Px_SetGain(fd,&gain)) {
        fprintf(stderr,"%s: ioctl(%s,setgain): %s\n",prgname,devicename,
                strerror(errno));
        exit(1);
    }
    exit(0);
}
